==> v1.0.0.tar.gz: merlin-cryosparc/merlin6-big/cluster_script.sh <==
#!/usr/bin/env bash
# cryoSPARC cluster submission script template for SLURM
# Lane: merlin6-big v1.0.0 (2019-09-18)
#
# This is the 'big' GPU configuration, meaning it requests exclusive access to
# the 4x GTX1080Ti nodes (with 11GB video RAM). Please use the normal gpu lane
# if possible.
#
# If you edit this file, run 'cryosparcm cluster connect'

{# This template uses jinja2 syntax. #}
{%- macro _min(a, b) -%}
  {%- if a <= b %}{{a}}{% else %}{{b}}{% endif -%}
{%- endmacro -%}

# Available variables:
#  script_path_abs={{ script_path_abs }}
#      - the absolute path to the generated submission script
#  run_cmd={{ run_cmd }}
#      - the complete command-line string to run the job
#  num_cpu={{ num_cpu }}
#      - the number of CPUs needed
#  num_gpu={{ num_gpu }}
#      - the number of GPUs needed. Note: the code will use this many GPUs
#        starting from dev id 0. The cluster scheduler or this script have the
#        responsibility of setting CUDA_VISIBLE_DEVICES so that the job code
#        ends up using the correct cluster-allocated GPUs.
#  ram_gb={{ ram_gb }}
#      - the amount of RAM needed in GB
#  job_dir_abs={{ job_dir_abs }}
#      - absolute path to the job directory
#  project_dir_abs={{ project_dir_abs }}
#      - absolute path to the project dir
#  job_log_path_abs={{ job_log_path_abs }}
#      - absolute path to the log file for the job
#  worker_bin_path={{ worker_bin_path }}
#      - absolute path to the cryosparc worker command
#  run_args={{ run_args }}
#      - arguments to be passed to cryosparcw run
#  project_uid={{ project_uid }}
#      - uid of the project
#  job_uid={{ job_uid }}
#      - uid of the job
#  job_creator={{ job_creator }}
#      - name of the user that created the job (may contain spaces)
#  cryosparc_username={{ cryosparc_username }}
#      - cryosparc username of the user that created the job (usually an email)

#SBATCH --job-name=cryosparc_{{ project_uid }}_{{ job_uid }}
#SBATCH --output={{ job_log_path_abs }}.out
#SBATCH --error={{ job_log_path_abs }}.err
#SBATCH --cpus-per-task=1
#SBATCH --threads-per-core=1
#SBATCH --exclusive

{%- if num_gpu == 0 %}
# Use CPU cluster
#SBATCH --partition=general
#SBATCH --account=merlin
#SBATCH --ntasks={{ num_cpu }}
#SBATCH --mem=352000
{%- else %}
# Use GPU cluster
#SBATCH --partition=gpu
#SBATCH --account=merlin-gpu
#SBATCH --mem=102400
#SBATCH --gres=gpu:GTX1080Ti:4
  {%- if num_gpu <= 2 %}
#SBATCH --ntasks={{ _min(num_cpu, 8) }}
  {%- else %}
    {# Slurm requests too many CPU sometimes; restrict to 20 per machine #}
    {%- set num_nodes = (num_gpu/4) | round(0, 'ceil') | int %}
#SBATCH --ntasks={{ _min(num_cpu, 20*num_nodes) }}
  {%- endif %}
{%- endif %}

# Print hostname, for debugging
hostname

# Make sure this matches the version of cuda used to compile cryosparc
module use unstable; module load cuda/10.0.130 2>/dev/null

srun {{ run_cmd }}

==> v1.3.0.tar.gz: merlin-cryosparc/merlin6-big/cluster_script.sh <==
#!/usr/bin/env bash
# cryoSPARC cluster submission script template for SLURM
# Lane: merlin6-big v1.3.0 (2020-07-14)
#
# This is the 'big' GPU configuration, meaning it requests exclusive access to
# the 4x GTX1080Ti/RTX2080Ti nodes (with 11GB video RAM). Please use the normal gpu
# lane if possible.
#
# If you edit this file, run 'cryosparcm cluster connect'

{# This template uses jinja2 syntax. #}
{%- macro _min(a, b) -%}
  {%- if a <= b %}{{a}}{% else %}{{b}}{% endif -%}
{%- endmacro -%}

# Available variables:
#  script_path_abs={{ script_path_abs }}
#      - the absolute path to the generated submission script
#  run_cmd={{ run_cmd }}
#      - the complete command-line string to run the job
#  num_cpu={{ num_cpu }}
#      - the number of CPUs needed
#  num_gpu={{ num_gpu }}
#      - the number of GPUs needed. Note: the code will use this many GPUs
#        starting from dev id 0. The cluster scheduler or this script have the
#        responsibility of setting CUDA_VISIBLE_DEVICES so that the job code
#        ends up using the correct cluster-allocated GPUs.
#  ram_gb={{ ram_gb }}
#      - the amount of RAM needed in GB
#  job_dir_abs={{ job_dir_abs }}
#      - absolute path to the job directory
#  project_dir_abs={{ project_dir_abs }}
#      - absolute path to the project dir
#  job_log_path_abs={{ job_log_path_abs }}
#      - absolute path to the log file for the job
#  worker_bin_path={{ worker_bin_path }}
#      - absolute path to the cryosparc worker command
#  run_args={{ run_args }}
#      - arguments to be passed to cryosparcw run
#  project_uid={{ project_uid }}
#      - uid of the project
#  job_uid={{ job_uid }}
#      - uid of the job
#  job_creator={{ job_creator }}
#      - name of the user that created the job (may contain spaces)
#  cryosparc_username={{ cryosparc_username }}
#      - cryosparc username of the user that created the job (usually an email)

#SBATCH --job-name=cryosparc_{{ project_uid }}_{{ job_uid }}
#SBATCH --output={{ job_log_path_abs }}.out
#SBATCH --error={{ job_log_path_abs }}.err
#SBATCH --nodes=1
#SBATCH --threads-per-core=1
#SBATCH --exclusive
#SBATCH --mem=0
#SBATCH --time=7-00:00:00

{%- if num_gpu == 0 %}
# Use CPU cluster
#SBATCH --partition=general
#SBATCH --account=merlin
#SBATCH --cpus-per-task={{ num_cpu }}
{%- else %}
# Use GPU cluster
#SBATCH --partition=gpu
#SBATCH --account=merlin-gpu
#SBATCH --gres=gpu:4
#SBATCH --exclude=merlin-g-00[1-5]
{%- endif %}

# Print hostname, for debugging
hostname

# Make sure this matches the version of cuda used to compile cryosparc
module purge
module load cuda/10.0.130

srun {{ run_cmd }}
